@@ -73,7 +73,7 @@ def create_column(lsf_json_folder_path, participant_id, location_list):
     location_label_column = []
     for loc in location_list:
         loc_label = "NF"
-        if loc != "NF":
+        if loc not in ["NF", "OB"]:
             matched_clusters = find_cluster_for_loc(loc, lsf_json)
             loc_label = find_label_for_cluster(matched_clusters, lsf_json)
             loc_label = list(set(loc_label))
